---
sidebar_position: 1
---

# npyodbc

What is npyodbc?

npyodbc is an extension to the Python C++ extension pyodbc. We are able to extend
pyodbc using the build system `meson`, which gives us the ability to overlay
additional functionality to the core codebase of pyodbc. In essence, npyodbc is an
extension to pyodbc, which is itself a C++ extension for Python.

In addition to including the core functionality of pyodbc, npyodbc includes dev
focused resources for aiding in getting a development environment set up.
